#!/usr/bin/sed -f
#
# utf8..latin1.sed
#
# Translate UTF8 characters to latin1 that GNU recode is unable to handle.
#
# This sed script belongs to utf8..latin1 (but also works on its own).
#
# Copyright (C) by Volker Kuhlmann
#               http://volker.top.geek.nz/contact.html
# All rights reserved.
# Released under the terms of the GNU General Public License (GPL) Version 2.
# See http://www.gnu.org/ for details.
#
# Volker Kuhlmann
#   1.0, 08 Jun 2013
#   1.1, 26 Jun 2013  Handle UTF-8 spaces.
#   1.1.2, 17 Oct 2013  Added U+03C0, U+2248.
#   1.1.3, 27 Feb 2015  Added U+25CF, U+2605, U+2606.
#			  U+FF08, U+FF09, U+FF1A, U+FF3B, U+FF3D.
#   1.1.4, 26 Sep 2022  Add U+2013, U+2014,  U+2015,
#			  L+R single+double quote marks.
#

#(Note: can't use latin1 characters in here because they are mutually
# exclusive with UTF8 ones in the same file.)

# Note: Find out the UTF8 bytes from the code point with
#   /bin/echo -en '\xff\x08' | recode utf16..utf8

# Line/paragraph separator: see
# http://www.unicode.org/reports/tr13/tr13-9.html

# sed command			# code point	UTF8	# ASC	UTF8 hex codes	Name
#				#			#(appr)

## Macrons
#s/\xc4\x80/A/g			# U+0100 A		# A	c4 80
#s/\xc4\x81/a/g			# U+0101 a		# a	c4 81
#s/\xc5\x8c/O/g			# U+014C O		# O	c5 8c
#s/\xc5\x8d/o/g			# U+014D o		# o	c5 8d
# Use transliterations instead (e.g. iconf -t latin1//translit).

# Spaces
s/\xe2\x80\x80/ /g		# U+2000 en		# SP	e2 80 80
s/\xe2\x80\x81/ /g		# U+2001 em		# SP	e2 80 81
s/\xe2\x80\x82/ /g		# U+2002 en		# SP	e2 80 82
s/\xe2\x80\x83/ /g		# U+2003 em		# SP	e2 80 83
s/\xe2\x80\x84/ /g		# U+2004 thick		# SP	e2 80 84
s/\xe2\x80\x85/ /g		# U+2005 mid		# SP	e2 80 85
s/\xe2\x80\x86/ /g		# U+2006 (thin)		# SP	e2 80 86
s/\xe2\x80\x87/ /g		# U+2007 figure		# SP	e2 80 87
s/\xe2\x80\x88/ /g		# U+2008 punct.		# SP	e2 80 88
s/\xe2\x80\x89/ /g		# U+2009 thin		# SP	e2 80 89
s/\xe2\x80\x8a/ /g		# U+200A hair		# SP	e2 80 8a
s/\xe2\x80\x8b//g		# U+200B ZWSP		# 	e2 80 8b

# Dashes
s/\xe2\x80\x93/-/g		# U+2013 en		# -	e2 80 93
s/\xe2\x80\x94/-/g		# U+2014 em		# -	e2 80 94
s/\xe2\x80\x95/-/g		# U+2015 horizontal bar	# -	e2 80 95

# Quote marks, apostrophes
s/\xe2\x80\x98/-/g		# U+2018 L single	# `	e2 80 98
s/\xe2\x80\x99/-/g		# U+2019 R single	# '	e2 80 99
s/\xe2\x80\x9c/-/g		# U+201C L double	# "	e2 80 9c
s/\xe2\x80\x9d/-/g		# U+201D R double	# "	e2 80 9d

# Format characters
s/\xe2\x80\xa8/\x0a/g		# U+2028 (LS)		# NL	e2 80 a8
s/\xe2\x80\xa9/\x0a\x0a/g	# U+2029 (PS)		# 	e2 80 a9

# Mathematics
s/\xcf\x80/pi/g			# U+03C0	π	# pi	cf 80
s/\xe2\x89\x88/appr/g		# U+2248	≈	# appr	e2 89 88

# ?
s/\xe2\x97\x8f/*/g		# U+25CF	●	# *	e2 97 8f	Black circle

# ?
s/\xe2\x98\x85/*/g		# U+2605	★	# star	e2 98 85	Black star
s/\xe2\x98\x85/*/g		# U+2606	☆	# star	e2 98 86	White star

# ?
s/\xef\xbc\x88/(/g		# U+FF08	（	# (	ef bc 88
s/\xef\xbc\x89/)/g		# U+FF09	）	# )	ef bc 89
s/\xef\xbc\x9a/:/g		# U+FF1A	：	# :	ef bc 9a
s/\xef\xbc\xbb/[/g		# U+FF3B	［	# [	ef bc bb
s/\xef\xbc\xbd/]/g		# U+FF3D	］	# ]	ef bc bd
